==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fAconst__5fnull.h <==
// class soot.coffi.Instruction_Aconst_null

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class d277e0c56f9063ea soot_coffi_Instruction__5fAconst__5fnull
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fAconst__5fnull_H_
#define _JC_soot_coffi_Instruction__5fAconst__5fnull_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fAconst__5fnull$sub_refs	_jc_soot_coffi_Instruction__5fAconst__5fnull$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fAconst__5fnull$sub_nonrefs	_jc_soot_coffi_Instruction__5fAconst__5fnull$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAconst__5fnull$refs	_jc_soot_coffi_Instruction__5fAconst__5fnull$refs;
typedef struct _jc_soot_coffi_Instruction__5fAconst__5fnull$nonrefs	_jc_soot_coffi_Instruction__5fAconst__5fnull$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAconst__5fnull$object	_jc_soot_coffi_Instruction__5fAconst__5fnull$object;

typedef const struct _jc_soot_coffi_Instruction__5fAconst__5fnull$vmethods	_jc_soot_coffi_Instruction__5fAconst__5fnull$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fAconst__5fnull$vtable	_jc_soot_coffi_Instruction__5fAconst__5fnull$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fAconst__5fnull$vtype	_jc_soot_coffi_Instruction__5fAconst__5fnull$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fAconst__5fnull$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fAconst__5fnull$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fAconst__5fnull$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fAconst__5fnull$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fAconst__5fnull$vmethods	soot_coffi_Instruction__5fAconst__5fnull;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fAconst__5fnull$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fAconst__5fnull$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAconst__5fnull$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAconst__5fnull$refs {
    _jc_soot_coffi_Instruction__5fAconst__5fnull$sub_refs	soot_coffi_Instruction__5fAconst__5fnull;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAconst__5fnull$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAconst__5fnull$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fAconst__5fnull$sub_nonrefs	soot_coffi_Instruction__5fAconst__5fnull;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fAconst__5fnull$object {
	_jc_soot_coffi_Instruction__5fAconst__5fnull$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fAconst__5fnull$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fAconst__5fnull$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fAconst__5fnull$vtype _jc_soot_coffi_Instruction__5fAconst__5fnull$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fAconst__5fnull, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fAconst__5fnull$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fAconst__5fnull_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fAconst__5fnull.h <==
// class soot.coffi.Instruction_Aconst_null

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class d277e0c56f9063ea soot_coffi_Instruction__5fAconst__5fnull
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fAconst__5fnull_H_
#define _JC_soot_coffi_Instruction__5fAconst__5fnull_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fAconst__5fnull$sub_refs	_jc_soot_coffi_Instruction__5fAconst__5fnull$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fAconst__5fnull$sub_nonrefs	_jc_soot_coffi_Instruction__5fAconst__5fnull$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAconst__5fnull$refs	_jc_soot_coffi_Instruction__5fAconst__5fnull$refs;
typedef struct _jc_soot_coffi_Instruction__5fAconst__5fnull$nonrefs	_jc_soot_coffi_Instruction__5fAconst__5fnull$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAconst__5fnull$object	_jc_soot_coffi_Instruction__5fAconst__5fnull$object;

typedef const struct _jc_soot_coffi_Instruction__5fAconst__5fnull$vmethods	_jc_soot_coffi_Instruction__5fAconst__5fnull$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fAconst__5fnull$vtable	_jc_soot_coffi_Instruction__5fAconst__5fnull$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fAconst__5fnull$vtype	_jc_soot_coffi_Instruction__5fAconst__5fnull$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fAconst__5fnull$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fAconst__5fnull$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fAconst__5fnull$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fAconst__5fnull$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fAconst__5fnull$vmethods	soot_coffi_Instruction__5fAconst__5fnull;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fAconst__5fnull$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fAconst__5fnull$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAconst__5fnull$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAconst__5fnull$refs {
    _jc_soot_coffi_Instruction__5fAconst__5fnull$sub_refs	soot_coffi_Instruction__5fAconst__5fnull;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAconst__5fnull$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAconst__5fnull$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fAconst__5fnull$sub_nonrefs	soot_coffi_Instruction__5fAconst__5fnull;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fAconst__5fnull$object {
	_jc_soot_coffi_Instruction__5fAconst__5fnull$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fAconst__5fnull$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fAconst__5fnull$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fAconst__5fnull$vtype _jc_soot_coffi_Instruction__5fAconst__5fnull$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fAconst__5fnull, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fAconst__5fnull$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fAconst__5fnull_H_ */
